package com.aucma.dms.mapper;

import com.aucma.dms.domain.DmsRecordAlarmInfo;

import java.util.List;

/**
 * 设备报警记录Mapper接口
 *
 * @author Yinq
 * @date 2024-08-13
 */
public interface DmsRecordAlarmInfoMapper {
    /**
     * 查询设备报警记录
     *
     * @param alarmId 设备报警记录主键
     * @return 设备报警记录
     */
    public DmsRecordAlarmInfo selectDmsRecordAlarmInfoByAlarmId(Long alarmId);

    /**
     * 查询设备报警记录列表
     *
     * @param dmsRecordAlarmInfo 设备报警记录
     * @return 设备报警记录集合
     */
    public List<DmsRecordAlarmInfo> selectDmsRecordAlarmInfoList(DmsRecordAlarmInfo dmsRecordAlarmInfo);

    /**
     * 新增设备报警记录
     *
     * @param dmsRecordAlarmInfo 设备报警记录
     * @return 结果
     */
    public int insertDmsRecordAlarmInfo(DmsRecordAlarmInfo dmsRecordAlarmInfo);

    /**
     * 修改设备报警记录
     *
     * @param dmsRecordAlarmInfo 设备报警记录
     * @return 结果
     */
    public int updateDmsRecordAlarmInfo(DmsRecordAlarmInfo dmsRecordAlarmInfo);

    /**
     * 删除设备报警记录
     *
     * @param alarmId 设备报警记录主键
     * @return 结果
     */
    public int deleteDmsRecordAlarmInfoByAlarmId(Long alarmId);

    /**
     * 批量删除设备报警记录
     *
     * @param alarmIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDmsRecordAlarmInfoByAlarmIds(Long[] alarmIds);
}
